#  _____    _     _  ___  ___ 
# |_   _| _(_)_ _(_)/ _ \/ __|
#   | || '_| \ V / | (_) \__ \
#   |_||_| |_|\_/|_|\___/|___/
#                             
# Copyright (C) 2023 - Group 8

{ pkgs, ... }: {

  system.stateVersion = "23.05";

  system.nixos = {
    distroName = "TriviOS";
    variant_id = "rpi3";
  };

  hardware.enableRedistributableFirmware = true;
  environment.systemPackages = with pkgs; [ libraspberrypi ];
  networking.wireless.enable = true;

  boot = {
    loader = {
      raspberryPi = {
        enable = true;
        version = 3;
        firmwareConfig = ''
          core_freq=250
        '';
      };
      grub.enable = false;
    };
    initrd.includeDefaultModules = false;
    kernelPackages = pkgs.linuxPackages_rpi3;
    kernelParams = [
      "console=ttyS1,115200n8"
    ];
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/B007-B007";
      fsType = "vfat";
      options = [ "umask=027" ];
    };
  };

  documentation = {
    enable = false;
    nixos.enable = false;
    man.enable = false;
    doc.enable = false;
    info.enable = false;
  };

  services.timesyncd.enable = false;
  systemd.oomd.enable = false;
  systemd.coredump.enable = false;
}
